########################
EncryptedPassportElement
########################


.. automodule:: litegram.enums.encrypted_passport_element
    :members:
    :member-order: bysource
    :undoc-members: True
